.demo-column {
  flex: 1 1 0;
  min-width: 0;
}

.src .CodeMirror {
  background-color: #fffffb;
  border: 1px solid #888;
  border-radius: 3px;
  box-shadow: 0 0 3px #ccc inset;
}

.dst .CodeMirror {
  background-color: #F8F8F8;
  border: 1px solid #ddd;
  border-radius: 3px;
}

.CodeMirror {
  flex: 1 1 auto;
  height: 100%;
  min-height: 0;
  font-size: 13px;
}

.CodeMirror .cm-comment {
  color: #baa;
}

.github-link {
  color: #333;
}
.github-link:hover {
  color: #000;
}
.github-link svg {
  display: block;
  fill: currentColor;
  height: 32px;
  width: 32px;
}
