'use strict'

module.exports = {
  valid_true: [true, true, true],
  valid_false: [false, false, false],
  deprecated_true: ['y', 'Y', 'yes', 'Yes', 'YES', 'on', 'On', 'ON'],
  deprecated_false: ['n', 'N', 'no', 'No', 'NO', 'off', 'Off', 'OFF']
}
